pub struct TextInput { /* private fields */ }
A single-line text field input. May be used as an evaluation for dependent form elements.

Examples

use tty_form::{
    step::CompoundStep,
    control::{Control, TextInput},
};

let mut step = CompoundStep::new();
TextInput::new("Enter your name:", false).add_to(&mut step);

Implementations

Create a new text input control with the specified prompt and casing-rules.

Update this input’s prompt text.

Specify whether this input should force its value to be lowercase.

Sets the dependency evaluation which other form elements can react to.