pub struct Coordinator<'a, 'b> { /* private fields */ }
Provides controlled access to a terminal interface. Coordinates allocation of lines and segments on the screen to elements.

Implementations

Set the cursor’s relative position.

Hide the cursor.

Retrieves the specified element’s inline segments.

Retrieve the specified element’s inline segment.

Retrieve a mutable reference to the specified element’s inline segment.

Retrieve the specified element’s inline line ID. This ID should be considered dirty between updates and after any block line updates.

Add an inline segment to the specified element and return a mutable reference to it.

Insert an inline segment at the specified index and return a mutable reference to it.

Remove the specified inline segment from the element.

Remove the inline segment at the specified index from the element.

Retrieves the specified element’s block lines.

Retrieve a specific block line for the specified element.

Retrieve a mutable reference to a specified block line for the specified element.

Append a block line to the specified element and return a mutable reference to it.

Insert a block line at the specified index and return a mutable reference to it.

Remove the specified block line from the element.

Remove a block line from the specified index.