Module dependency

Module dependency 

Structs

DependencyId
A unique identifier.
DependencyState

Enums

Action
An action to apply to the target if the source evaluates true.
Evaluation
An evaluation to apply to the source of a dependency.