Enum tty_form::dependency::Action
source · [−]pub enum Action {
Hide,
Show,
}Expand description
An action to apply to the target if the source evaluates true.
Variants
Hide
If the evaluation is true for the source, the target is hidden, otherwise it is shown.
Show
If the evaluation is false for the source, the target is shown, otherwise it is hidden.