pub trait InputDevice {
// Required method
fn read(&mut self) -> Result<Event>;
}Expand description
An input device to use for controlling a form.
pub trait InputDevice {
// Required method
fn read(&mut self) -> Result<Event>;
}An input device to use for controlling a form.