Module tty_form::step

source ·

Structs

A single-line step which controls multple controls including static and input elements.
A key-value-pair set entry step.
A multi-line text input step.
A boolean input which, if true, accepts a text description.

Enums

After processing an input event, an action may be returned to the form from the step.

Traits

A distinct, vertically-separated phase of the form.