pub trait Step {
    fn initialize(&mut self, dependency_state: &mut DependencyState, index: usize);
    fn render(
        &self,
        interface: &mut Interface<'_>,
        dependency_state: &DependencyState,
        position: Position,
        is_focused: bool
    ) -> u16; fn update(
        &mut self,
        dependency_state: &mut DependencyState,
        input: KeyEvent
    ) -> Option<InputResult>; fn help(&self) -> Segment; fn drawer(&self) -> Option<DrawerContents>; fn result(&self, dependency_state: &DependencyState) -> String; fn add_to(self, form: &mut Form); }
A distinct, vertically-separated phase of the form.

Required Methods

Perform any post-configuration initialization actions for this step.

Render this step at the specified position and return the height of the rendered content.

Handle the specified input event, optionally returning an instruction for the form.

Retrieve this step’s current help text.

Retrieve this step’s current drawer contents, if applicable.

Retrieves this step’s final WYSIWYG result.

Complete configuration and add this step to the form.

Implementors