pub struct TextInput { /* private fields */ }Expand description
A single-line text field input. May be used as an evaluation for dependent form elements.
Examples
use tty_form::{
step::CompoundStep,
control::{Control, TextInput},
};
let mut step = CompoundStep::new();
TextInput::new("Enter your name:", false).add_to(&mut step);Implementations
sourceimpl TextInput
impl TextInput
sourcepub fn new(prompt: &str, force_lowercase: bool) -> Self
pub fn new(prompt: &str, force_lowercase: bool) -> Self
Create a new text input control with the specified prompt and casing-rules.
sourcepub fn set_prompt(&mut self, prompt: &str)
pub fn set_prompt(&mut self, prompt: &str)
Update this input’s prompt text.
sourcepub fn set_force_lowercase(&mut self, force: bool)
pub fn set_force_lowercase(&mut self, force: bool)
Specify whether this input should force its value to be lowercase.
sourcepub fn set_evaluation(&mut self, evaluation: Evaluation) -> DependencyId
pub fn set_evaluation(&mut self, evaluation: Evaluation) -> DependencyId
Sets the dependency evaluation which other form elements can react to.